translate.convert.po2prop

Package translate :: Package convert :: Module po2prop |
[hide private]
[frames] | no frames]

# Module po2prop

source code

convert Gettext PO localization files to Java/Mozilla .properties files

see: http://translate.sourceforge.net/wiki/toolkit/po2prop for examples and usage instructions

Classes | [hide private]
| reprop

Functions | [hide private]
convertstrings(inputfile, outputfile, templatefile, personality="strings", includefuzzy=False, encoding=None) .strings specific convertor function | source code
convertmozillaprop(inputfile, outputfile, templatefile, includefuzzy=False) Mozilla specific convertor function | source code
convertprop(inputfile, outputfile, templatefile, personality="java", includefuzzy=False, encoding=None) | source code
main(argv=None) | source code

Variables | [hide private]
| eol = `"\n"`
| formats = `{("po", "properties"):("properties", convertprop), (`...``

Imports: quote, po, properties

Variables Details | [hide private]

  ### formats Value:
      {("po", "properties"):("properties", convertprop), ("po", "lang"):("la
      ng", convertprop), ("po", "strings"):("strings", convertstrings),}